#!/bin/sh
# usr/opt/wrdapp/slope_area/test/test.sh -- run SLOPE_AREA (SAC) test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop]] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          10/06/93, rsregan, modified for use with slope_area
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROG=$TOPDIR/bin/sac
  PROGNM=SAC
  END=5
  DIVD=========================================

  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                             # by default, stop at 5
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    if [ $Start -gt $END ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# begin test runs
#
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi
#
# remove old output file
  $CLEAN
#
# begin test runs
#
  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    Name=example$Test
    rm -f go
    echo 1 > go
    echo $DATA/$Name.dat >> go
    echo $Name.out >> go
    if [ $Test -eq 1 ]
    then
      echo Slope-area reach example with level-water surface in cross sections >> go
    elif [ $Test -eq 2 ]
    then
      echo Slope-area reach: Snake Creek near Connell, WA for flood of Feb. 21, 1956 >> go
    elif [ $Test -eq 3 ]
    then
      echo Sloping water surface with conveyance weighting >> go
    elif [ $Test -eq 4 ]
    then
      echo Slope-area reach example with level-water surface in cross sections, metric output >> go
    elif [ $Test -eq 5 ]
    then
      echo Simple reach example with metric input and feet-second output >> go
    fi
    echo
    $PROG < go
    Test=`expr $Test + 1`
  done
#
  if [ $Test -ge $Start ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Stop"
    echo
  fi

# check output against original output in $DATA directory
  $CHECK example
